# AA-dens test data

The data present here can be generated by using the following command:

```shell
python ../myauth/manage.py test dens.tests.testdata.create_eveuniverse --keepdb -v 2
```

See the [eveuniverse documentation](https://django-eveuniverse.readthedocs.io/en/latest/developer.html#test-data) for
more information
